@@ -1,7 +1,5 @@
 WeibullReg <- function (formula, data = parent.frame(), conf.level = 0.95){
-
-    alpha <- 1 - conf.level
     m <- survival::survreg(formula, data, dist = "weibull")
-    mle <- ConvertWeibull(m, alpha)
+    mle <- ConvertWeibull(m, conf.level = conf.level)
     return(list(formula = formula, coef = mle$vars, HR = mle$HR, ETR = mle$ETR, summary = summary(m)))
 }
